@@ -1,7 +1,7 @@
 package Perinci::Examples::Completion;
 
 our $DATE = '2019-06-29'; # DATE
-our $VERSION = '0.813'; # VERSION
+our $VERSION = '0.814'; # VERSION
 
 use 5.010;
 use strict;
@@ -47,15 +47,16 @@ $SPEC{fruits} = {
             pos => 0,
             slurpy => 1,
         },
-        animals => {
+        category => {
             summary => 'This argument contains valid values and '.
                 'their summaries in the schema',
             schema => ['str*' => {
-                in => [qw/flamingo frog rabbit/],
+                in => [qw/citrus tropical melon stone/],
                 'x.in.summaries' => [
-                    "Aren't your foot tired?",
-                    "What if you don't turn after I kiss you?",
-                    "What's up doc?",
+                    "Oranges, grapefruits, pomelos",
+                    "Bananas, mangoes",
+                    "Watermelons, honeydews",
+                    "Apricots, nectarines, peaches",
                 ],
             }],
         },
@@ -85,7 +86,7 @@ Perinci::Examples::Completion - More completion examples
 
 =head1 VERSION
 
-This document describes version 0.813 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-06-29.
+This document describes version 0.814 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-06-29.
 
 =for Pod::Coverage .*
 
@@ -106,7 +107,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<animals> => I<str>
+=item * B<category> => I<str>
 
 This argument contains valid values and their summaries in the schema.
 
